@@ -13,6 +13,7 @@ SERVICE_PROVIDERS = {
     "AZURE": "Azure",
     "CHROMA": "Chroma",
     "CREWAI": "CrewAI",
+    "DEEPSEEK": "DeepSeek",
     "DSPY": "DSPy",
     "GROQ": "Groq",
     "LANGCHAIN": "Langchain",
@@ -37,6 +38,7 @@ SERVICE_PROVIDERS = {
     "MONGODB": "MongoDB",
     "AWS_BEDROCK": "AWS Bedrock",
     "CEREBRAS": "Cerebras",
+    "MILVUS": "Milvus",
 }
 
 LANGTRACE_ADDITIONAL_SPAN_ATTRIBUTES_KEY = "langtrace_additional_attributes"
